@@ -80,14 +80,14 @@ extern "C"
  * @param name The token name.
  * @param value The token value.
  */
-#define osip_accept_param_add(header,name,value)  osip_generic_param_add((header)->gen_params,name,value)
+#define osip_accept_param_add(header,name,value)  osip_generic_param_add((&(header)->gen_params),name,value)
 /**
  * Find a header parameter in an Accept element.
  * @param header The element to work on.
  * @param name The token name to search.
  * @param dest A pointer on the element found.
  */
-#define osip_accept_param_get_byname(header,name,dest) osip_generic_param_get_byname((header)->gen_params,name,dest)
+#define osip_accept_param_get_byname(header,name,dest) osip_generic_param_get_byname((&(header)->gen_params),name,dest)
 
 
 #ifdef __cplusplus
