@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -35,8 +35,8 @@
  */
 
 /**
- * Structure for Route headers.
- * @defvar osip_route_t
+ * Structure for Record-Route headers.
+ * @var osip_record_route_t
  */
   typedef osip_from_t osip_record_route_t;
 
@@ -97,14 +97,14 @@ extern "C"
  * @param name The token name.
  * @param value The token value.
  */
-#define osip_record_route_param_add(header,name,value) osip_generic_param_add((header)->gen_params,name,value)
+#define osip_record_route_param_add(header,name,value) osip_generic_param_add((&(header)->gen_params),name,value)
 /**
  * Find a header parameter in a Record-Route element.
  * @param header The element to work on.
  * @param name The token name to search.
  * @param dest A pointer on the element found.
  */
-#define osip_record_route_param_get_byname(header,name,dest) osip_generic_param_get_byname((header)->gen_params,name,dest)
+#define osip_record_route_param_get_byname(header,name,dest) osip_generic_param_get_byname((&(header)->gen_params),name,dest)
 
 #ifdef __cplusplus
 }
