@@ -33,6 +33,17 @@
 #	define HAVE_TIME_H 1
 #	define HAVE_STDARG_H 1
 
+#elif defined _WIN32_WCE
+
+#define STDC_HEADERS 1
+#define HAVE_CTYPE_H 1
+#define HAVE_STRING_H 1
+#define HAVE_TIME_H 1
+#define HAVE_STDARG_H 1
+
+#define snprintf  _snprintf
+#define EBUSY           16
+
 #elif defined(WIN32)
 
 #define STDC_HEADERS 1
@@ -42,24 +53,14 @@
 #define HAVE_TIME_H 1
 #define HAVE_STDARG_H 1
 
+#define snprintf _snprintf
+
 /* use win32 crypto routines for random number generation */
 /* only use for vs .net (compiler v. 1300) or greater */
 #if _MSC_VER >= 1300
 #define WIN32_USE_CRYPTO 1
 #endif
 
-#elif defined _WIN32_WCE
-
-#define STDC_HEADERS 1
-#define HAVE_CTYPE_H 1
-#define HAVE_STRING_H 1
-#define HAVE_TIME_H 1
-#define HAVE_STDARG_H 1
-
-#define strnicmp	_strnicmp
-#define stricmp		_stricmp
-#define EBUSY           16
-
 #endif
 
 #ifdef __VXWORKS_OS__
@@ -72,8 +73,8 @@
 #define VA_START(a, f)  va_start(a, f)
 
 /* VxWorks lacks support for snprintf */
-int osip_vsnprintf( char* buf, int max, const char *fmt, va_list ap);
-int osip_snprintf(  char *buf, int max, const char *fmt, ...);
+int osip_vsnprintf (char *buf, int max, const char *fmt, va_list ap);
+int osip_snprintf (char *buf, int max, const char *fmt, ...);
 
 #define snprintf  osip_snprintf
 #define vsnprintf osip_vsnprintf
@@ -133,8 +134,20 @@ int osip_snprintf(  char *buf, int max, const char *fmt, ...);
 
 #ifdef __PSOS__
 #define VA_START(a, f)  va_start(a, f)
+#include "pna.h"
+#include "stdlib.h"
+#include "time.h"
+#define timercmp(tvp, uvp, cmp) \
+        ((tvp)->tv_sec cmp (uvp)->tv_sec || \
+         (tvp)->tv_sec == (uvp)->tv_sec && (tvp)->tv_usec cmp (uvp)->tv_usec)
+#define snprintf  osip_snprintf
+#ifndef INT_MAX
+#define INT_MAX 0x7FFFFFFF
 #endif
 
+#endif
+
+
 #if __STDC__
 #  ifndef NOPROTOS
 #    define PARAMS(args)   args
@@ -164,19 +177,38 @@ extern "C"
 /* MALLOC redirections    */
 /**************************/
 
-#ifndef WIN32
+#if !defined(WIN32) && !defined(_WIN32_WCE)
 
-typedef void *osip_malloc_func_t(size_t size);
-typedef void osip_free_func_t(void *ptr);
-typedef void *osip_realloc_func_t(void *ptr, size_t size);
+  typedef void *osip_malloc_func_t (size_t size);
+  typedef void osip_free_func_t (void *ptr);
+  typedef void *osip_realloc_func_t (void *ptr, size_t size);
 
-extern osip_malloc_func_t  *osip_malloc_func;
-extern osip_realloc_func_t *osip_realloc_func;
-extern osip_free_func_t    *osip_free_func;
+  extern osip_malloc_func_t *osip_malloc_func;
+  extern osip_realloc_func_t *osip_realloc_func;
+  extern osip_free_func_t *osip_free_func;
 
-void osip_set_allocators(osip_malloc_func_t  *malloc_func, 
-                         osip_realloc_func_t *realloc_func, 
-                         osip_free_func_t    *free_func);
+  void osip_set_allocators (osip_malloc_func_t * malloc_func,
+                            osip_realloc_func_t * realloc_func,
+                            osip_free_func_t * free_func);
+
+
+#ifdef DEBUG_MEM
+
+  void *_osip_malloc (size_t size, char *file, unsigned short line);
+  void _osip_free (void *ptr);
+  void *_osip_realloc (void *ptr, size_t size, char *file, unsigned short line);
+
+#ifndef osip_malloc
+#define osip_malloc(S) _osip_malloc(S,__FILE__,__LINE__)
+#endif
+#ifndef osip_realloc
+#define osip_realloc(P,S) _osip_realloc(P,S,__FILE__,__LINE__)
+#endif
+#ifndef osip_free
+#define osip_free(P) { if (P!=NULL) { _osip_free(P); } }
+#endif
+
+#else
 
 #ifndef osip_malloc
 #define osip_malloc(S) (osip_malloc_func?osip_malloc_func(S):malloc(S))
@@ -188,10 +220,14 @@ void osip_set_allocators(osip_malloc_func_t  *malloc_func,
 #define osip_free(P) { if (P!=NULL) { if (osip_free_func) osip_free_func(P); else free(P);} }
 #endif
 
+#endif
+
 #else
-void *osip_malloc(size_t size);
-void *osip_realloc(void *, size_t size);
-void osip_free(void *);
+
+  void *osip_malloc (size_t size);
+  void *osip_realloc (void *, size_t size);
+  void osip_free (void *);
+
 #endif
 
 #ifdef WIN32
@@ -223,9 +259,9 @@ void osip_free(void *);
   int osip_tolower (char *word);
   int osip_clrspace (char *word);
   char *__osip_sdp_append_string (char *string, size_t size,
-				  char *cur, char *string_osip_to_append);
+                                  char *cur, char *string_osip_to_append);
   int __osip_set_next_token (char **dest, char *buf, int end_separator,
-			     char **next);
+                             char **next);
   /* find the next unescaped quote and return its index. */
   char *__osip_quote_find (const char *qstring);
   char *osip_enquote (const char *s);
@@ -234,6 +270,11 @@ void osip_free(void *);
   int osip_strcasecmp (const char *s1, const char *s2);
   int osip_strncasecmp (const char *s1, const char *s2, size_t len);
 
+  unsigned long osip_hash (const char *str);
+  char *osip_str_append (char *dst, const char *src);
+  char *osip_strn_append (char *dst, const char *src, size_t len);
+  char *osip_clrncpy (char *dst, const char *src, size_t len);
+
 /**************************/
 /* LOG&DEBUG support      */
 /**************************/
@@ -264,11 +305,13 @@ void osip_free(void *);
   osip_trace_level_t;
 
 
-typedef void osip_trace_func_t(char *fi, int li, osip_trace_level_t level, char *chfr, va_list ap);
+  typedef void osip_trace_func_t (char *fi, int li, osip_trace_level_t level,
+                                  char *chfr, va_list ap);
 
 /* these are defined in all cases, but are empty when oSIP is compiled
    without trace */
-  void osip_trace_initialize_func (osip_trace_level_t level, osip_trace_func_t *func);
+  void osip_trace_initialize_func (osip_trace_level_t level,
+                                   osip_trace_func_t * func);
   void osip_trace_initialize_syslog (osip_trace_level_t level, char *ident);
   void osip_trace_initialize (osip_trace_level_t level, FILE * file);
   void osip_trace_enable_until_level (osip_trace_level_t level);
@@ -298,7 +341,7 @@ typedef void osip_trace_func_t(char *fi, int li, osip_trace_level_t level, char
 /* INPUT: f | use f instead of default log file    */
 /* INPUT: chfr | format string for next args       */
   int osip_trace (char *fi, int li, osip_trace_level_t level, FILE * f,
-		  char *chfr, ...);
+                  char *chfr, ...);
 
 #ifdef ENABLE_TRACE
 #define OSIP_TRACE(P) P
@@ -306,8 +349,49 @@ typedef void osip_trace_func_t(char *fi, int li, osip_trace_level_t level, char
 #define OSIP_TRACE(P) do {} while (0)
 #endif
 
+#define REMOVE_ELEMENT(first_element, element)   \
+       if (element->parent==NULL)                \
+	{ first_element = element->next;         \
+          if (first_element!=NULL)               \
+          first_element->parent = NULL; }        \
+       else \
+        { element->parent->next = element->next; \
+          if (element->next!=NULL)               \
+	element->next->parent = element->parent; \
+	element->next = NULL;                    \
+	element->parent = NULL; }
+
+#define ADD_ELEMENT(first_element, element) \
+   if (first_element==NULL)                 \
+    {                                       \
+      first_element   = element;            \
+      element->next   = NULL;               \
+      element->parent = NULL;               \
+    }                                       \
+  else                                      \
+    {                                       \
+      element->next   = first_element;      \
+      element->parent = NULL;               \
+      element->next->parent = element;      \
+      first_element = element;              \
+    }
+
+#define APPEND_ELEMENT(type_of_element_t, first_element, element) \
+  if (first_element==NULL)                            \
+    { first_element = element;                        \
+      element->next   = NULL; /* useless */           \
+      element->parent = NULL; /* useless */ }         \
+  else                                                \
+    { type_of_element_t *f;                           \
+      for (f=first_element; f->next!=NULL; f=f->next) \
+         { }                                          \
+      f->next    = element;                           \
+      element->parent = f;                            \
+      element->next   = NULL;                         \
+    }
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif				/* _PORT_H_ */
+#endif                          /* _PORT_H_ */
