@@ -142,7 +142,7 @@ osip_transaction_init (osip_transaction_t ** transaction,
   (*transaction)->transactionid = transactionid;
   transactionid++;
 
-  topvia = osip_list_get (request->vias, 0);
+  topvia = osip_list_get (&request->vias, 0);
   if (topvia == NULL)
     goto ti_error_1;
 
@@ -419,6 +419,15 @@ osip_transaction_get_destination (osip_transaction_t * transaction, char **ip,
   return -1;
 }
 
+int
+osip_transaction_set_srv_record(osip_transaction_t *transaction, osip_srv_record_t *record)
+{
+	if (transaction==NULL)
+		return -1;
+	memcpy(&transaction->record, record, sizeof(osip_srv_record_t));
+	return 0;
+}
+
 int
 osip_transaction_set_your_instance (osip_transaction_t * transaction,
                                     void *instance)
@@ -480,7 +489,7 @@ __osip_transaction_matching_response_osip_to_xict_17_1_3 (osip_transaction_t *
       response == NULL || response->cseq == NULL || response->cseq->method == NULL)
     return -1;
 
-  topvia_response = osip_list_get (response->vias, 0);
+  topvia_response = osip_list_get (&response->vias, 0);
   if (topvia_response == NULL)
     {
       OSIP_TRACE (osip_trace
@@ -575,7 +584,7 @@ __osip_transaction_matching_request_osip_to_xist_17_2_3 (osip_transaction_t *
       request == NULL || request->cseq == NULL || request->cseq->method == NULL)
     return -1;
 
-  topvia_request = osip_list_get (request->vias, 0);
+  topvia_request = osip_list_get (&request->vias, 0);
   if (topvia_request == NULL)
     {
       OSIP_TRACE (osip_trace
@@ -600,6 +609,9 @@ __osip_transaction_matching_request_osip_to_xist_17_2_3 (osip_transaction_t *
   if (b_origrequest != NULL && b_request != NULL)
     /* case where both request contains a branch */
     {
+      if ( ! b_origrequest->gvalue ) return -1;
+      if ( ! b_request->gvalue )     return -1;
+
       length_br = strlen (b_origrequest->gvalue);
       length_br2 = strlen (b_request->gvalue);
       if (length_br != length_br2)
