@@ -135,7 +135,7 @@ sdp_message_i_info_set (sdp_message_t * sdp, int pos_media, char *info)
       sdp->i_info = info;
       return 0;
     }
-  med = osip_list_get (sdp->m_medias, pos_media);
+  med = osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
     return -1;
   med->i_info = info;
@@ -153,7 +153,7 @@ sdp_message_i_info_get (sdp_message_t * sdp, int pos_media)
     {
       return sdp->i_info;
     }
-  med = osip_list_get (sdp->m_medias, pos_media);
+  med = osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
     return NULL;
   return med->i_info;
@@ -181,7 +181,7 @@ sdp_message_e_email_add (sdp_message_t * sdp, char *email)
 {
   if (sdp == NULL)
     return -1;
-  osip_list_add (sdp->e_emails, email, -1);
+  osip_list_add (&sdp->e_emails, email, -1);
   return 0;
 }
 
@@ -190,8 +190,8 @@ sdp_message_e_email_get (sdp_message_t * sdp, int pos)
 {
   if (sdp == NULL)
     return NULL;
-  if (osip_list_size (sdp->e_emails) > pos)
-    return (char *) osip_list_get (sdp->e_emails, pos);
+  if (osip_list_size (&sdp->e_emails) > pos)
+    return (char *) osip_list_get (&sdp->e_emails, pos);
   return NULL;
 }
 
@@ -200,7 +200,7 @@ sdp_message_p_phone_add (sdp_message_t * sdp, char *phone)
 {
   if (sdp == NULL)
     return -1;
-  osip_list_add (sdp->p_phones, phone, -1);
+  osip_list_add (&sdp->p_phones, phone, -1);
   return 0;
 }
 
@@ -209,8 +209,8 @@ sdp_message_p_phone_get (sdp_message_t * sdp, int pos)
 {
   if (sdp == NULL)
     return NULL;
-  if (osip_list_size (sdp->p_phones) > pos)
-    return (char *) osip_list_get (sdp->p_phones, pos);
+  if (osip_list_size (&sdp->p_phones) > pos)
+    return (char *) osip_list_get (&sdp->p_phones, pos);
   return NULL;
 }
 
@@ -226,7 +226,7 @@ sdp_message_c_connection_add (sdp_message_t * sdp, int pos_media,
 
   if (sdp == NULL)
     return -1;
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return -1;
   i = sdp_connection_init (&conn);
   if (i != 0)
@@ -241,8 +241,8 @@ sdp_message_c_connection_add (sdp_message_t * sdp, int pos_media,
       sdp->c_connection = conn;
       return 0;
     }
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
-  osip_list_add (med->c_connections, conn, -1);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
+  osip_list_add (&med->c_connections, conn, -1);
   return 0;
 }
 
@@ -256,10 +256,10 @@ sdp_message_connection_get (sdp_message_t * sdp, int pos_media, int pos)
     return NULL;
   if (pos_media == -1)          /* pos is useless in this case: 1 global "c=" is allowed */
     return sdp->c_connection;
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
     return NULL;
-  return (sdp_connection_t *) osip_list_get (med->c_connections, pos);
+  return (sdp_connection_t *) osip_list_get (&med->c_connections, pos);
 }
 
 char *
@@ -322,7 +322,7 @@ sdp_message_b_bandwidth_add (sdp_message_t * sdp, int pos_media, char *bwtype,
 
   if (sdp == NULL)
     return -1;
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return -1;
   i = sdp_bandwidth_init (&band);
   if (i != 0)
@@ -331,11 +331,11 @@ sdp_message_b_bandwidth_add (sdp_message_t * sdp, int pos_media, char *bwtype,
   band->b_bandwidth = bandwidth;
   if (pos_media == -1)
     {
-      osip_list_add (sdp->b_bandwidths, band, -1);
+      osip_list_add (&sdp->b_bandwidths, band, -1);
       return 0;
     }
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
-  osip_list_add (med->b_bandwidths, band, -1);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
+  osip_list_add (&med->b_bandwidths, band, -1);
   return 0;
 }
 
@@ -347,11 +347,11 @@ sdp_message_bandwidth_get (sdp_message_t * sdp, int pos_media, int pos)
   if (sdp == NULL)
     return NULL;
   if (pos_media == -1)
-    return (sdp_bandwidth_t *) osip_list_get (sdp->b_bandwidths, pos);
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+    return (sdp_bandwidth_t *) osip_list_get (&sdp->b_bandwidths, pos);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
     return NULL;
-  return (sdp_bandwidth_t *) osip_list_get (med->b_bandwidths, pos);
+  return (sdp_bandwidth_t *) osip_list_get (&med->b_bandwidths, pos);
 }
 
 char *
@@ -387,7 +387,7 @@ sdp_message_t_time_descr_add (sdp_message_t * sdp, char *start, char *stop)
     return -1;
   td->t_start_time = start;
   td->t_stop_time = stop;
-  osip_list_add (sdp->t_descrs, td, -1);
+  osip_list_add (&sdp->t_descrs, td, -1);
   return 0;
 }
 
@@ -398,7 +398,7 @@ sdp_message_t_start_time_get (sdp_message_t * sdp, int pos_td)
 
   if (sdp == NULL)
     return NULL;
-  td = (sdp_time_descr_t *) osip_list_get (sdp->t_descrs, pos_td);
+  td = (sdp_time_descr_t *) osip_list_get (&sdp->t_descrs, pos_td);
   if (td == NULL)
     return NULL;
   return td->t_start_time;
@@ -411,7 +411,7 @@ sdp_message_t_stop_time_get (sdp_message_t * sdp, int pos_td)
 
   if (sdp == NULL)
     return NULL;
-  td = (sdp_time_descr_t *) osip_list_get (sdp->t_descrs, pos_td);
+  td = (sdp_time_descr_t *) osip_list_get (&sdp->t_descrs, pos_td);
   if (td == NULL)
     return NULL;
   return td->t_stop_time;
@@ -424,10 +424,10 @@ sdp_message_r_repeat_add (sdp_message_t * sdp, int pos_time_descr, char *field)
 
   if (sdp == NULL)
     return -1;
-  td = (sdp_time_descr_t *) osip_list_get (sdp->t_descrs, pos_time_descr);
+  td = (sdp_time_descr_t *) osip_list_get (&sdp->t_descrs, pos_time_descr);
   if (td == NULL)
     return -1;
-  osip_list_add (td->r_repeats, field, -1);
+  osip_list_add (&td->r_repeats, field, -1);
   return 0;
 }
 
@@ -438,10 +438,10 @@ sdp_message_r_repeat_get (sdp_message_t * sdp, int pos_time_descr, int pos_repea
 
   if (sdp == NULL)
     return NULL;
-  td = (sdp_time_descr_t *) osip_list_get (sdp->t_descrs, pos_time_descr);
+  td = (sdp_time_descr_t *) osip_list_get (&sdp->t_descrs, pos_time_descr);
   if (td == NULL)
     return NULL;
-  return (char *) osip_list_get (td->r_repeats, pos_repeat);
+  return (char *) osip_list_get (&td->r_repeats, pos_repeat);
 }
 
 int
@@ -470,7 +470,7 @@ sdp_message_k_key_set (sdp_message_t * sdp, int pos_media, char *keytype,
 
   if (sdp == NULL)
     return -1;
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return -1;
   sdp_key_init (&key);
   key->k_keytype = keytype;
@@ -480,7 +480,7 @@ sdp_message_k_key_set (sdp_message_t * sdp, int pos_media, char *keytype,
       sdp->k_key = key;
       return 0;
     }
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   med->k_key = key;
   return 0;
 }
@@ -498,9 +498,9 @@ sdp_message_k_keytype_get (sdp_message_t * sdp, int pos_media)
         return NULL;
       return sdp->k_key->k_keytype;
     }
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return NULL;
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med->k_key == NULL)
     return NULL;
   return med->k_key->k_keytype;
@@ -519,9 +519,9 @@ sdp_message_k_keydata_get (sdp_message_t * sdp, int pos_media)
         return NULL;
       return sdp->k_key->k_keydata;
     }
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return NULL;
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med->k_key == NULL)
     return NULL;
   return med->k_key->k_keydata;
@@ -537,7 +537,7 @@ sdp_message_a_attribute_add (sdp_message_t * sdp, int pos_media,
 
   if (sdp == NULL)
     return -1;
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return -1;
   i = sdp_attribute_init (&attr);
   if (i != 0)
@@ -546,11 +546,11 @@ sdp_message_a_attribute_add (sdp_message_t * sdp, int pos_media,
   attr->a_att_value = att_value;
   if (pos_media == -1)
     {
-      osip_list_add (sdp->a_attributes, attr, -1);
+      osip_list_add (&sdp->a_attributes, attr, -1);
       return 0;
     }
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
-  osip_list_add (med->a_attributes, attr, -1);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
+  osip_list_add (&med->a_attributes, attr, -1);
   return 0;
 }
 
@@ -563,31 +563,31 @@ sdp_message_a_attribute_del (sdp_message_t * sdp, int pos_media, char *att_field
 
   if (sdp == NULL)
     return -1;
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return -1;
   if (pos_media == -1)
     {
-      for (i = 0; i < osip_list_size (sdp->a_attributes);)
+      for (i = 0; i < osip_list_size (&sdp->a_attributes);)
         {
-          attr = osip_list_get (sdp->a_attributes, i);
+          attr = osip_list_get (&sdp->a_attributes, i);
           if (strcmp (attr->a_att_field, att_field) == 0)
             {
-              osip_list_remove (sdp->a_attributes, i);
+              osip_list_remove (&sdp->a_attributes, i);
               sdp_attribute_free (attr);
           } else
             i++;
         }
       return 0;
     }
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
     return -1;
-  for (i = 0; i < osip_list_size (med->a_attributes);)
+  for (i = 0; i < osip_list_size (&med->a_attributes);)
     {
-      attr = osip_list_get (med->a_attributes, i);
+      attr = osip_list_get (&med->a_attributes, i);
       if (strcmp (attr->a_att_field, att_field) == 0)
         {
-          osip_list_remove (med->a_attributes, i);
+          osip_list_remove (&med->a_attributes, i);
           sdp_attribute_free (attr);
       } else
         i++;
@@ -605,46 +605,46 @@ sdp_message_a_attribute_del_at_index (sdp_message_t * sdp, int pos_media,
 
   if (sdp == NULL)
     return -1;
-  if ((pos_media != -1) && (osip_list_size (sdp->m_medias) < pos_media + 1))
+  if ((pos_media != -1) && (osip_list_size (&sdp->m_medias) < pos_media + 1))
     return -1;
   if (pos_media == -1)
     {
       if (pos_attr == -1)
         {
-          for (i = 0; i < osip_list_size (sdp->a_attributes);)
+          for (i = 0; i < osip_list_size (&sdp->a_attributes);)
             {
-              attr = osip_list_get (sdp->a_attributes, i);
+              attr = osip_list_get (&sdp->a_attributes, i);
               if (strcmp (attr->a_att_field, att_field) == 0)
                 {
-                  osip_list_remove (sdp->a_attributes, i);
+                  osip_list_remove (&sdp->a_attributes, i);
                   sdp_attribute_free (attr);
               } else
                 i++;
             }
-      } else if ((attr = osip_list_get (sdp->a_attributes, pos_attr)) != NULL)
+      } else if ((attr = osip_list_get (&sdp->a_attributes, pos_attr)) != NULL)
         {
-          osip_list_remove (sdp->a_attributes, pos_attr);
+          osip_list_remove (&sdp->a_attributes, pos_attr);
           sdp_attribute_free (attr);
         }
       return 0;
     }
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
     return -1;
-  for (i = 0; i < osip_list_size (med->a_attributes);)
+  for (i = 0; i < osip_list_size (&med->a_attributes);)
     {
       if (pos_attr == -1)
         {
-          attr = osip_list_get (med->a_attributes, i);
+          attr = osip_list_get (&med->a_attributes, i);
           if (strcmp (attr->a_att_field, att_field) == 0)
             {
-              osip_list_remove (med->a_attributes, i);
+              osip_list_remove (&med->a_attributes, i);
               sdp_attribute_free (attr);
           } else
             i++;
-      } else if ((attr = osip_list_get (med->a_attributes, pos_attr)) != NULL)
+      } else if ((attr = osip_list_get (&med->a_attributes, pos_attr)) != NULL)
         {
-          osip_list_remove (med->a_attributes, pos_attr);
+          osip_list_remove (&med->a_attributes, pos_attr);
           sdp_attribute_free (attr);
         }
     }
@@ -660,11 +660,11 @@ sdp_message_attribute_get (sdp_message_t * sdp, int pos_media, int pos)
   if (sdp == NULL)
     return NULL;
   if (pos_media == -1)
-    return (sdp_attribute_t *) osip_list_get (sdp->a_attributes, pos);
-  med = (sdp_media_t *) osip_list_get (sdp->m_medias, pos_media);
+    return (sdp_attribute_t *) osip_list_get (&sdp->a_attributes, pos);
+  med = (sdp_media_t *) osip_list_get (&sdp->m_medias, pos_media);
   if (med == NULL)
     return NULL;
-  return (sdp_attribute_t *) osip_list_get (med->a_attributes, pos);
+  return (sdp_attribute_t *) osip_list_get (&med->a_attributes, pos);
 }
 
 char *
@@ -694,7 +694,7 @@ sdp_message_endof_media (sdp_message_t * sdp, int i)
     return -1;
   if (i == -1)
     return 0;
-  if (!osip_list_eol (sdp->m_medias, i))
+  if (!osip_list_eol (&sdp->m_medias, i))
     return 0;                   /* not end of list */
   return -1;                    /* end of list */
 }
@@ -713,14 +713,14 @@ sdp_message_m_media_add (sdp_message_t * sdp, char *media,
   med->m_port = port;
   med->m_number_of_port = number_of_port;
   med->m_proto = proto;
-  osip_list_add (sdp->m_medias, med, -1);
+  osip_list_add (&sdp->m_medias, med, -1);
   return 0;
 }
 
 char *
 sdp_message_m_media_get (sdp_message_t * sdp, int pos_media)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
     return NULL;
@@ -730,7 +730,7 @@ sdp_message_m_media_get (sdp_message_t * sdp, int pos_media)
 char *
 sdp_message_m_port_get (sdp_message_t * sdp, int pos_media)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
     return NULL;
@@ -740,7 +740,7 @@ sdp_message_m_port_get (sdp_message_t * sdp, int pos_media)
 char *
 sdp_message_m_number_of_port_get (sdp_message_t * sdp, int pos_media)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
     return NULL;
@@ -750,7 +750,7 @@ sdp_message_m_number_of_port_get (sdp_message_t * sdp, int pos_media)
 int
 sdp_message_m_port_set (sdp_message_t * sdp, int pos_media, char *port)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
     return -1;
@@ -763,7 +763,7 @@ sdp_message_m_port_set (sdp_message_t * sdp, int pos_media, char *port)
 char *
 sdp_message_m_proto_get (sdp_message_t * sdp, int pos_media)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
     return NULL;
@@ -773,35 +773,35 @@ sdp_message_m_proto_get (sdp_message_t * sdp, int pos_media)
 int
 sdp_message_m_payload_add (sdp_message_t * sdp, int pos_media, char *payload)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
     return -1;
-  osip_list_add (med->m_payloads, payload, -1);
+  osip_list_add (&med->m_payloads, payload, -1);
   return 0;
 }
 
 char *
 sdp_message_m_payload_get (sdp_message_t * sdp, int pos_media, int pos)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
 
   if (med == NULL)
     return NULL;
-  return (char *) osip_list_get (med->m_payloads, pos);
+  return (char *) osip_list_get (&med->m_payloads, pos);
 }
 
 int
 sdp_message_m_payload_del (sdp_message_t * sdp, int pos_media, int pos)
 {
-  sdp_media_t *med = osip_list_get (sdp->m_medias, pos_media);
+  sdp_media_t *med = osip_list_get (&sdp->m_medias, pos_media);
   char *payload;
 
   if (med == NULL)
     return -1;
-  if ((payload = osip_list_get (med->m_payloads, pos)) == NULL)
+  if ((payload = osip_list_get (&med->m_payloads, pos)) == NULL)
     return -1;
-  osip_list_remove (med->m_payloads, pos);
+  osip_list_remove (&med->m_payloads, pos);
   osip_free (payload);
   return 0;
 }
